from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07"


@dataclass
class AccountSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ActiveCurrencyAndAmount:
    value: Optional[Decimal] = field(
        default=None,
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        },
    )


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


@dataclass
class CashAccountType2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ClearingSystemIdentification2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 5,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class FinancialIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericIdentification30:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class MessageHeader1:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    cre_dt_tm: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class PaymentIdentification8:
    instr_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "InstrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )
    end_to_end_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "EndToEndId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    tx_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )
    uetr: Optional[str] = field(
        default=None,
        metadata={
            "name": "UETR",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}",
        },
    )


@dataclass
class ProxyAccountType1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class AddressType3Choice:
    cd: Optional[AddressType2Code] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    prtry: Optional[GenericIdentification30] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class Amount2Choice:
    amt_wtht_ccy: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "AmtWthtCcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    amt_wth_ccy: Optional[ActiveCurrencyAndAmount] = field(
        default=None,
        metadata={
            "name": "AmtWthCcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class ClearingSystemMemberIdentification2:
    clr_sys_id: Optional[ClearingSystemIdentification2Choice] = field(
        default=None,
        metadata={
            "name": "ClrSysId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    mmb_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericAccountIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 34,
        },
    )
    schme_nm: Optional[AccountSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericFinancialIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[FinancialIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ProxyAccountIdentification1:
    tp: Optional[ProxyAccountType1Choice] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
            "min_length": 1,
            "max_length": 2048,
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
        },
    )


@dataclass
class AccountIdentification4Choice:
    iban: Optional[str] = field(
        default=None,
        metadata={
            "name": "IBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}",
        },
    )
    othr: Optional[GenericAccountIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class PostalAddress27:
    adr_tp: Optional[AddressType3Choice] = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    care_of: Optional[str] = field(
        default=None,
        metadata={
            "name": "CareOf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 70,
        },
    )
    sub_dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "SubDept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    bldg_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 16,
        },
    )
    bldg_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    flr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Flr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 70,
        },
    )
    unit_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "UnitNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_bx: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstBx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 16,
        },
    )
    room: Optional[str] = field(
        default=None,
        metadata={
            "name": "Room",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    twn_lctn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnLctnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dstrct_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "DstrctNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    ctry_sub_dvsn: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    adr_line: List[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "max_occurs": 7,
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class BranchData5:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class CashAccount40:
    id: Optional[AccountIdentification4Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    tp: Optional[CashAccountType2Choice] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z]{3,3}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 70,
        },
    )
    prxy: Optional[ProxyAccountIdentification1] = field(
        default=None,
        metadata={
            "name": "Prxy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class FinancialInstitutionIdentification23:
    bicfi: Optional[str] = field(
        default=None,
        metadata={
            "name": "BICFI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    clr_sys_mmb_id: Optional[ClearingSystemMemberIdentification2] = field(
        default=None,
        metadata={
            "name": "ClrSysMmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    othr: Optional[GenericFinancialIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class BranchAndFinancialInstitutionIdentification8:
    fin_instn_id: Optional[FinancialInstitutionIdentification23] = field(
        default=None,
        metadata={
            "name": "FinInstnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
        },
    )
    brnch_id: Optional[BranchData5] = field(
        default=None,
        metadata={
            "name": "BrnchId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class LiquidityCreditTransfer4:
    lqdty_trf_id: Optional[PaymentIdentification8] = field(
        default=None,
        metadata={
            "name": "LqdtyTrfId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    cdtr: Optional[BranchAndFinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "Cdtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    cdtr_acct: Optional[CashAccount40] = field(
        default=None,
        metadata={
            "name": "CdtrAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    trfd_amt: Optional[Amount2Choice] = field(
        default=None,
        metadata={
            "name": "TrfdAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
        },
    )
    dbtr: Optional[BranchAndFinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "Dbtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    dbtr_acct: Optional[CashAccount40] = field(
        default=None,
        metadata={
            "name": "DbtrAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )
    sttlm_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "SttlmDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class LiquidityCreditTransferV07:
    msg_hdr: Optional[MessageHeader1] = field(
        default=None,
        metadata={
            "name": "MsgHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
        },
    )
    lqdty_cdt_trf: Optional[LiquidityCreditTransfer4] = field(
        default=None,
        metadata={
            "name": "LqdtyCdtTrf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
            "required": True,
        },
    )
    splmtry_data: List[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:camt.050.001.07"

    lqdty_cdt_trf: Optional[LiquidityCreditTransferV07] = field(
        default=None,
        metadata={
            "name": "LqdtyCdtTrf",
            "type": "Element",
            "required": True,
        },
    )



from pyiso20022.pacs.pacs_009_001_01.pacs_009_001_01 import (
    AccountIdentification3Choice,
    AddressType2Code,
    BranchAndFinancialInstitutionIdentification3,
    BranchData,
    CashAccount7,
    CashAccountType2,
    CashAccountType4Code,
    CashClearingSystem3Code,
    ClearingChannel2Code,
    ClearingSystemIdentification1Choice,
    ClearingSystemMemberIdentification3Choice,
    CreditTransferTransactionInformation3,
    CurrencyAndAmount,
    Document,
    FinancialInstitutionIdentification3,
    FinancialInstitutionIdentification5Choice,
    GenericIdentification3,
    GroupHeader4,
    Instruction4Code,
    Instruction5Code,
    InstructionForCreditorAgent2,
    InstructionForNextAgent1,
    NameAndAddress7,
    Pacs00900101,
    PaymentIdentification2,
    PaymentTypeInformation5,
    PostalAddress1,
    Priority2Code,
    RemittanceInformation2,
    RestrictedProprietaryChoice,
    SettlementDateTimeIndication1,
    SettlementInformation1,
    SettlementMethod1Code,
    SettlementTimeRequest1,
    SimpleIdentificationInformation2,
)

__all__ = [
    "AccountIdentification3Choice",
    "AddressType2Code",
    "BranchAndFinancialInstitutionIdentification3",
    "BranchData",
    "CashAccount7",
    "CashAccountType2",
    "CashAccountType4Code",
    "CashClearingSystem3Code",
    "ClearingChannel2Code",
    "ClearingSystemIdentification1Choice",
    "ClearingSystemMemberIdentification3Choice",
    "CreditTransferTransactionInformation3",
    "CurrencyAndAmount",
    "Document",
    "FinancialInstitutionIdentification3",
    "FinancialInstitutionIdentification5Choice",
    "GenericIdentification3",
    "GroupHeader4",
    "Instruction4Code",
    "Instruction5Code",
    "InstructionForCreditorAgent2",
    "InstructionForNextAgent1",
    "NameAndAddress7",
    "PaymentIdentification2",
    "PaymentTypeInformation5",
    "PostalAddress1",
    "Priority2Code",
    "RemittanceInformation2",
    "RestrictedProprietaryChoice",
    "SettlementDateTimeIndication1",
    "SettlementInformation1",
    "SettlementMethod1Code",
    "SettlementTimeRequest1",
    "SimpleIdentificationInformation2",
    "Pacs00900101",
]



from pyiso20022.camt.camt_050_001_07.camt_050_001_07 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    Amount2Choice,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    CashAccount40,
    CashAccountType2Choice,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification23,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    LiquidityCreditTransfer4,
    LiquidityCreditTransferV07,
    MessageHeader1,
    PaymentIdentification8,
    PostalAddress27,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "Amount2Choice",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "CashAccount40",
    "CashAccountType2Choice",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification23",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "LiquidityCreditTransfer4",
    "LiquidityCreditTransferV07",
    "MessageHeader1",
    "PaymentIdentification8",
    "PostalAddress27",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08"


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


@dataclass
class ClearingSystemIdentification2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 5,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class DateAndPlaceOfBirth1:
    birth_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "BirthDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    prvc_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "PrvcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    city_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CityOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        },
    )


@dataclass
class FinancialIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericIdentification30:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


class NamePrefix2Code(Enum):
    DOCT = "DOCT"
    MADM = "MADM"
    MISS = "MISS"
    MIST = "MIST"
    MIKS = "MIKS"


@dataclass
class OrganisationIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class OriginalMessageAndIssuer1:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    msg_nm_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgNmId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    orgtr_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "OrgtrNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class OtherContact1:
    chanl_tp: Optional[str] = field(
        default=None,
        metadata={
            "name": "ChanlTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 4,
        },
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 128,
        },
    )


class PaymentInstrument1Code(Enum):
    BDT = "BDT"
    BCT = "BCT"
    CDT = "CDT"
    CCT = "CCT"
    CHK = "CHK"
    BKT = "BKT"
    DCP = "DCP"
    CCP = "CCP"
    RTI = "RTI"
    CAN = "CAN"


@dataclass
class PersonIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


class PreferredContactMethod2Code(Enum):
    MAIL = "MAIL"
    FAXX = "FAXX"
    LETT = "LETT"
    CELL = "CELL"
    ONLI = "ONLI"
    PHON = "PHON"


@dataclass
class QueueTransactionIdentification1:
    qid: Optional[str] = field(
        default=None,
        metadata={
            "name": "QId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        },
    )
    pos_in_q: Optional[str] = field(
        default=None,
        metadata={
            "name": "PosInQ",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        },
    )


@dataclass
class RequestStatus1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class StatusReason6Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class AddressType3Choice:
    cd: Optional[AddressType2Code] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    prtry: Optional[GenericIdentification30] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class ClearingSystemMemberIdentification2:
    clr_sys_id: Optional[ClearingSystemIdentification2Choice] = field(
        default=None,
        metadata={
            "name": "ClrSysId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    mmb_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class Contact13:
    nm_prfx: Optional[NamePrefix2Code] = field(
        default=None,
        metadata={
            "name": "NmPrfx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    phne_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "PhneNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    mob_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "MobNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    fax_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "FaxNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    urladr: Optional[str] = field(
        default=None,
        metadata={
            "name": "URLAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 2048,
        },
    )
    email_adr: Optional[str] = field(
        default=None,
        metadata={
            "name": "EmailAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 256,
        },
    )
    email_purp: Optional[str] = field(
        default=None,
        metadata={
            "name": "EmailPurp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    job_titl: Optional[str] = field(
        default=None,
        metadata={
            "name": "JobTitl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    rspnsblty: Optional[str] = field(
        default=None,
        metadata={
            "name": "Rspnsblty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )
    othr: List[OtherContact1] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    prefrd_mtd: Optional[PreferredContactMethod2Code] = field(
        default=None,
        metadata={
            "name": "PrefrdMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class GenericFinancialIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[FinancialIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericOrganisationIdentification3:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 256,
        },
    )
    schme_nm: Optional[OrganisationIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericPersonIdentification2:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 256,
        },
    )
    schme_nm: Optional[PersonIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class PaymentOrigin1Choice:
    finmt: Optional[str] = field(
        default=None,
        metadata={
            "name": "FINMT",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[0-9]{1,3}",
        },
    )
    xmlmsg_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "XMLMsgNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    instrm: Optional[PaymentInstrument1Code] = field(
        default=None,
        metadata={
            "name": "Instrm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class RequestType4Choice:
    pmt_ctrl: Optional[str] = field(
        default=None,
        metadata={
            "name": "PmtCtrl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    enqry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Enqry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[GenericIdentification1] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )


@dataclass
class MessageHeader9:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    cre_dt_tm: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    req_tp: Optional[RequestType4Choice] = field(
        default=None,
        metadata={
            "name": "ReqTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class OrganisationIdentification39:
    any_bic: Optional[str] = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    othr: List[GenericOrganisationIdentification3] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class PersonIdentification18:
    dt_and_plc_of_birth: Optional[DateAndPlaceOfBirth1] = field(
        default=None,
        metadata={
            "name": "DtAndPlcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    othr: List[GenericPersonIdentification2] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class PostalAddress27:
    adr_tp: Optional[AddressType3Choice] = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    care_of: Optional[str] = field(
        default=None,
        metadata={
            "name": "CareOf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )
    sub_dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "SubDept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    bldg_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 16,
        },
    )
    bldg_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    flr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Flr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )
    unit_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "UnitNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_bx: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstBx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 16,
        },
    )
    room: Optional[str] = field(
        default=None,
        metadata={
            "name": "Room",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    twn_lctn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnLctnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dstrct_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "DstrctNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    ctry_sub_dvsn: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    adr_line: List[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "max_occurs": 7,
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class BranchData5:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class FinancialInstitutionIdentification23:
    bicfi: Optional[str] = field(
        default=None,
        metadata={
            "name": "BICFI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    clr_sys_mmb_id: Optional[ClearingSystemMemberIdentification2] = field(
        default=None,
        metadata={
            "name": "ClrSysMmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    othr: Optional[GenericFinancialIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class Party52Choice:
    org_id: Optional[OrganisationIdentification39] = field(
        default=None,
        metadata={
            "name": "OrgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    prvt_id: Optional[PersonIdentification18] = field(
        default=None,
        metadata={
            "name": "PrvtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class BranchAndFinancialInstitutionIdentification8:
    fin_instn_id: Optional[FinancialInstitutionIdentification23] = field(
        default=None,
        metadata={
            "name": "FinInstnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    brnch_id: Optional[BranchData5] = field(
        default=None,
        metadata={
            "name": "BrnchId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class PartyIdentification272:
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    id: Optional[Party52Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    ctry_of_res: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfRes",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    ctct_dtls: Optional[Contact13] = field(
        default=None,
        metadata={
            "name": "CtctDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class LongPaymentIdentification4:
    tx_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    uetr: Optional[str] = field(
        default=None,
        metadata={
            "name": "UETR",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}",
        },
    )
    intr_bk_sttlm_amt: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "IntrBkSttlmAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    intr_bk_sttlm_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "IntrBkSttlmDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    pmt_mtd: Optional[PaymentOrigin1Choice] = field(
        default=None,
        metadata={
            "name": "PmtMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    instg_agt: Optional[BranchAndFinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "InstgAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    instd_agt: Optional[BranchAndFinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "InstdAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    ntry_tp: Optional[str] = field(
        default=None,
        metadata={
            "name": "NtryTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[BEOVW]{1,1}[0-9]{2,2}|DUM",
        },
    )
    end_to_end_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "EndToEndId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ShortPaymentIdentification4:
    tx_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    uetr: Optional[str] = field(
        default=None,
        metadata={
            "name": "UETR",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}",
        },
    )
    intr_bk_sttlm_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "IntrBkSttlmDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    instg_agt: Optional[BranchAndFinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "InstgAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )


@dataclass
class StatusReasonInformation14:
    orgtr: Optional[PartyIdentification272] = field(
        default=None,
        metadata={
            "name": "Orgtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    rsn: Optional[StatusReason6Choice] = field(
        default=None,
        metadata={
            "name": "Rsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    addtl_inf: List[str] = field(
        default_factory=list,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 105,
        },
    )


@dataclass
class PaymentIdentification8Choice:
    tx_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 35,
        },
    )
    uetr: Optional[str] = field(
        default=None,
        metadata={
            "name": "UETR",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "pattern": r"[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}",
        },
    )
    qid: Optional[QueueTransactionIdentification1] = field(
        default=None,
        metadata={
            "name": "QId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    lng_biz_id: Optional[LongPaymentIdentification4] = field(
        default=None,
        metadata={
            "name": "LngBizId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    shrt_biz_id: Optional[ShortPaymentIdentification4] = field(
        default=None,
        metadata={
            "name": "ShrtBizId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    prtry_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class RequestHandling3:
    sts: Optional[RequestStatus1Choice] = field(
        default=None,
        metadata={
            "name": "Sts",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    sts_rsn: Optional[StatusReasonInformation14] = field(
        default=None,
        metadata={
            "name": "StsRsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class Receipt6:
    orgnl_msg_id: Optional[OriginalMessageAndIssuer1] = field(
        default=None,
        metadata={
            "name": "OrgnlMsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    orgnl_pmt_id: Optional[PaymentIdentification8Choice] = field(
        default=None,
        metadata={
            "name": "OrgnlPmtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )
    req_hdlg: List[RequestHandling3] = field(
        default_factory=list,
        metadata={
            "name": "ReqHdlg",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class ReceiptV08:
    msg_hdr: Optional[MessageHeader9] = field(
        default=None,
        metadata={
            "name": "MsgHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "required": True,
        },
    )
    rct_dtls: List[Receipt6] = field(
        default_factory=list,
        metadata={
            "name": "RctDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
            "min_occurs": 1,
        },
    )
    splmtry_data: List[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:camt.025.001.08"

    rct: Optional[ReceiptV08] = field(
        default=None,
        metadata={
            "name": "Rct",
            "type": "Element",
            "required": True,
        },
    )



from pyiso20022.camt.camt_028_001_01.camt_028_001_01 import (
    Account1,
    AccountIdentification1,
    AccountIdentification1Choice,
    AddressType2Code,
    AmountType1Choice,
    BranchAndFinancialInstitutionIdentification,
    BranchData,
    Camt02800101,
    Case,
    CaseAssignment,
    CashAccount3,
    CashAccountType3Code,
    ClearingSystemMemberIdentificationChoice,
    CurrencyAndAmount,
    Document,
    DocumentType1Code,
    EquivalentAmount,
    FinancialInstitutionIdentification1,
    GenericIdentification1,
    GenericIdentification3,
    GenericIdentification4,
    Intermediary1,
    LongPostalAddress1Choice,
    NameAndAddress2,
    NonFinancialInstitutionIdentification1,
    Party1Choice,
    PartyIdentification1,
    PartyIdentification1Choice,
    PaymentComplementaryInformation,
    PaymentInstructionExtract,
    PersonIdentification2,
    PostalAddress1,
    ReferredDocumentAmount1Choice,
    RemittanceInformation3Choice,
    SimpleIdentificationInformation,
    StructuredLongPostalAddress1,
    StructuredRemittanceInformation2,
)

__all__ = [
    "Account1",
    "AccountIdentification1",
    "AccountIdentification1Choice",
    "AddressType2Code",
    "AmountType1Choice",
    "BranchAndFinancialInstitutionIdentification",
    "BranchData",
    "Case",
    "CaseAssignment",
    "CashAccount3",
    "CashAccountType3Code",
    "ClearingSystemMemberIdentificationChoice",
    "CurrencyAndAmount",
    "Document",
    "DocumentType1Code",
    "EquivalentAmount",
    "FinancialInstitutionIdentification1",
    "GenericIdentification1",
    "GenericIdentification3",
    "GenericIdentification4",
    "Intermediary1",
    "LongPostalAddress1Choice",
    "NameAndAddress2",
    "NonFinancialInstitutionIdentification1",
    "Party1Choice",
    "PartyIdentification1",
    "PartyIdentification1Choice",
    "PaymentComplementaryInformation",
    "PaymentInstructionExtract",
    "PersonIdentification2",
    "PostalAddress1",
    "ReferredDocumentAmount1Choice",
    "RemittanceInformation3Choice",
    "SimpleIdentificationInformation",
    "StructuredLongPostalAddress1",
    "StructuredRemittanceInformation2",
    "Camt02800101",
]



from pyiso20022.camt.camt_052_001_07.camt_052_001_07 import (
    AccountIdentification4Choice,
    AccountInterest4,
    AccountReport22,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAnd13DecimalAmount,
    ActiveOrHistoricCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmountRange2,
    AddressType2Code,
    AmountAndCurrencyExchange3,
    AmountAndCurrencyExchangeDetails3,
    AmountAndCurrencyExchangeDetails4,
    AmountAndDirection35,
    AmountRangeBoundary1,
    AttendanceContext1Code,
    AuthenticationEntity1Code,
    AuthenticationMethod1Code,
    BalanceSubType1Choice,
    BalanceType10Choice,
    BalanceType13,
    BankToCustomerAccountReportV07,
    BankTransactionCodeStructure4,
    BankTransactionCodeStructure5,
    BankTransactionCodeStructure6,
    BatchInformation2,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    CardAggregated2,
    CardDataReading1Code,
    CardEntry3,
    CardholderAuthentication2,
    CardholderVerificationCapability1Code,
    CardIndividualTransaction2,
    CardPaymentServiceType2Code,
    CardSecurityInformation1,
    CardSequenceNumberRange1,
    CardTransaction3Choice,
    CardTransaction16,
    CashAccount24,
    CashAccount36,
    CashAccountType2Choice,
    CashAvailability1,
    CashAvailabilityDate1Choice,
    CashBalance8,
    CashDeposit1,
    ChargeBearerType1Code,
    Charges4,
    ChargesRecord2,
    ChargeType3Choice,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    ContactDetails2,
    CopyDuplicate1Code,
    CorporateAction9,
    CreditDebitCode,
    CreditLine3,
    CreditLineType1Choice,
    CreditorReferenceInformation2,
    CreditorReferenceType1Choice,
    CreditorReferenceType2,
    Cscmanagement1Code,
    CurrencyExchange5,
    DateAndDateTime2Choice,
    DateAndPlaceOfBirth1,
    DateOrDateTimePeriod1Choice,
    DatePeriod2,
    DateTimePeriod1,
    DiscountAmountAndType1,
    DiscountAmountType1Choice,
    DisplayCapabilities1,
    Document,
    DocumentAdjustment1,
    DocumentLineIdentification1,
    DocumentLineInformation1,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType3Code,
    DocumentType6Code,
    EntryDetails8,
    EntryStatus1Choice,
    EntryTransaction9,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification8,
    FinancialInstrumentQuantityChoice,
    FromToAmountRange1,
    Garnishment2,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification3,
    GenericIdentification30,
    GenericIdentification32,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader73,
    IdentificationSource3Choice,
    ImpliedCurrencyAmountRange1Choice,
    InterestRecord2,
    InterestType1Choice,
    InterestType1Code,
    LocalInstrument2Choice,
    MessageIdentification2,
    NameAndAddress10,
    NamePrefix1Code,
    NumberAndSumOfTransactions1,
    NumberAndSumOfTransactions4,
    OnLineCapability1Code,
    OrganisationIdentification8,
    OrganisationIdentificationSchemeName1Choice,
    OriginalAndCurrentQuantities1,
    OriginalBusinessQuery1,
    OtherIdentification1,
    Pagination1,
    Party34Choice,
    Party35Choice,
    PartyIdentification125,
    PartyType3Code,
    PartyType4Code,
    PaymentCard4,
    PaymentContext3,
    PaymentReturnReason3,
    PersonIdentification13,
    PersonIdentificationSchemeName1Choice,
    PlainCardData1,
    PoicomponentType1Code,
    PointOfInteraction1,
    PointOfInteractionCapabilities1,
    PointOfInteractionComponent1,
    PostalAddress6,
    Price7,
    PriceRateOrAmount3Choice,
    PriceValueType1Code,
    Product2,
    ProprietaryAgent3,
    ProprietaryBankTransactionCodeStructure1,
    ProprietaryDate3,
    ProprietaryParty4,
    ProprietaryPrice2,
    ProprietaryQuantity1,
    ProprietaryReference1,
    Purpose2Choice,
    Rate4,
    RateType4Choice,
    ReferredDocumentInformation7,
    ReferredDocumentType3Choice,
    ReferredDocumentType4,
    RemittanceAmount2,
    RemittanceAmount3,
    RemittanceInformation15,
    RemittanceLocation4,
    RemittanceLocationDetails1,
    RemittanceLocationMethod2Code,
    ReportEntry9,
    ReportingSource1Choice,
    ReturnReason5Choice,
    SecuritiesAccount19,
    SecurityIdentification19,
    SequenceRange1,
    SequenceRange1Choice,
    StructuredRemittanceInformation15,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount2,
    TaxAmountAndType1,
    TaxAmountType1Choice,
    TaxAuthorisation1,
    TaxCharges2,
    TaxInformation6,
    TaxInformation7,
    TaxParty1,
    TaxParty2,
    TaxPeriod2,
    TaxRecord2,
    TaxRecordDetails2,
    TaxRecordPeriod1Code,
    TechnicalInputChannel1Choice,
    TotalsPerBankTransactionCode5,
    TotalTransactions6,
    TrackData1,
    TransactionAgents4,
    TransactionChannel1Code,
    TransactionDates3,
    TransactionEnvironment1Code,
    TransactionIdentifier1,
    TransactionInterest4,
    TransactionParties4,
    TransactionPrice4Choice,
    TransactionQuantities2Choice,
    TransactionReferences3,
    UnitOfMeasure1Code,
    UserInterface2Code,
    YieldedOrValueType1Choice,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountInterest4",
    "AccountReport22",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAnd13DecimalAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmountRange2",
    "AddressType2Code",
    "AmountAndCurrencyExchange3",
    "AmountAndCurrencyExchangeDetails3",
    "AmountAndCurrencyExchangeDetails4",
    "AmountAndDirection35",
    "AmountRangeBoundary1",
    "AttendanceContext1Code",
    "AuthenticationEntity1Code",
    "AuthenticationMethod1Code",
    "BalanceSubType1Choice",
    "BalanceType10Choice",
    "BalanceType13",
    "BankToCustomerAccountReportV07",
    "BankTransactionCodeStructure4",
    "BankTransactionCodeStructure5",
    "BankTransactionCodeStructure6",
    "BatchInformation2",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "Cscmanagement1Code",
    "CardAggregated2",
    "CardDataReading1Code",
    "CardEntry3",
    "CardIndividualTransaction2",
    "CardPaymentServiceType2Code",
    "CardSecurityInformation1",
    "CardSequenceNumberRange1",
    "CardTransaction16",
    "CardTransaction3Choice",
    "CardholderAuthentication2",
    "CardholderVerificationCapability1Code",
    "CashAccount24",
    "CashAccount36",
    "CashAccountType2Choice",
    "CashAvailability1",
    "CashAvailabilityDate1Choice",
    "CashBalance8",
    "CashDeposit1",
    "ChargeBearerType1Code",
    "ChargeType3Choice",
    "Charges4",
    "ChargesRecord2",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "ContactDetails2",
    "CopyDuplicate1Code",
    "CorporateAction9",
    "CreditDebitCode",
    "CreditLine3",
    "CreditLineType1Choice",
    "CreditorReferenceInformation2",
    "CreditorReferenceType1Choice",
    "CreditorReferenceType2",
    "CurrencyExchange5",
    "DateAndDateTime2Choice",
    "DateAndPlaceOfBirth1",
    "DateOrDateTimePeriod1Choice",
    "DatePeriod2",
    "DateTimePeriod1",
    "DiscountAmountAndType1",
    "DiscountAmountType1Choice",
    "DisplayCapabilities1",
    "Document",
    "DocumentAdjustment1",
    "DocumentLineIdentification1",
    "DocumentLineInformation1",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType3Code",
    "DocumentType6Code",
    "EntryDetails8",
    "EntryStatus1Choice",
    "EntryTransaction9",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification8",
    "FinancialInstrumentQuantityChoice",
    "FromToAmountRange1",
    "Garnishment2",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification3",
    "GenericIdentification30",
    "GenericIdentification32",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader73",
    "IdentificationSource3Choice",
    "ImpliedCurrencyAmountRange1Choice",
    "InterestRecord2",
    "InterestType1Choice",
    "InterestType1Code",
    "LocalInstrument2Choice",
    "MessageIdentification2",
    "NameAndAddress10",
    "NamePrefix1Code",
    "NumberAndSumOfTransactions1",
    "NumberAndSumOfTransactions4",
    "OnLineCapability1Code",
    "OrganisationIdentification8",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalAndCurrentQuantities1",
    "OriginalBusinessQuery1",
    "OtherIdentification1",
    "PoicomponentType1Code",
    "Pagination1",
    "Party34Choice",
    "Party35Choice",
    "PartyIdentification125",
    "PartyType3Code",
    "PartyType4Code",
    "PaymentCard4",
    "PaymentContext3",
    "PaymentReturnReason3",
    "PersonIdentification13",
    "PersonIdentificationSchemeName1Choice",
    "PlainCardData1",
    "PointOfInteraction1",
    "PointOfInteractionCapabilities1",
    "PointOfInteractionComponent1",
    "PostalAddress6",
    "Price7",
    "PriceRateOrAmount3Choice",
    "PriceValueType1Code",
    "Product2",
    "ProprietaryAgent3",
    "ProprietaryBankTransactionCodeStructure1",
    "ProprietaryDate3",
    "ProprietaryParty4",
    "ProprietaryPrice2",
    "ProprietaryQuantity1",
    "ProprietaryReference1",
    "Purpose2Choice",
    "Rate4",
    "RateType4Choice",
    "ReferredDocumentInformation7",
    "ReferredDocumentType3Choice",
    "ReferredDocumentType4",
    "RemittanceAmount2",
    "RemittanceAmount3",
    "RemittanceInformation15",
    "RemittanceLocation4",
    "RemittanceLocationDetails1",
    "RemittanceLocationMethod2Code",
    "ReportEntry9",
    "ReportingSource1Choice",
    "ReturnReason5Choice",
    "SecuritiesAccount19",
    "SecurityIdentification19",
    "SequenceRange1",
    "SequenceRange1Choice",
    "StructuredRemittanceInformation15",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount2",
    "TaxAmountAndType1",
    "TaxAmountType1Choice",
    "TaxAuthorisation1",
    "TaxCharges2",
    "TaxInformation6",
    "TaxInformation7",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod2",
    "TaxRecord2",
    "TaxRecordDetails2",
    "TaxRecordPeriod1Code",
    "TechnicalInputChannel1Choice",
    "TotalTransactions6",
    "TotalsPerBankTransactionCode5",
    "TrackData1",
    "TransactionAgents4",
    "TransactionChannel1Code",
    "TransactionDates3",
    "TransactionEnvironment1Code",
    "TransactionIdentifier1",
    "TransactionInterest4",
    "TransactionParties4",
    "TransactionPrice4Choice",
    "TransactionQuantities2Choice",
    "TransactionReferences3",
    "UnitOfMeasure1Code",
    "UserInterface2Code",
    "YieldedOrValueType1Choice",
]



from pyiso20022.pacs.pacs_009_001_10.pacs_009_001_10 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    BranchAndFinancialInstitutionIdentification6,
    BranchData3,
    CashAccount40,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemIdentification3Choice,
    ClearingSystemMemberIdentification2,
    Contact4,
    CreditDebitCode,
    CreditorReferenceInformation2,
    CreditorReferenceType1Choice,
    CreditorReferenceType2,
    CreditTransferTransaction52,
    CreditTransferTransaction56,
    DateAndPlaceOfBirth1,
    DatePeriod2,
    DiscountAmountAndType1,
    DiscountAmountType1Choice,
    Document,
    DocumentAdjustment1,
    DocumentLineIdentification1,
    DocumentLineInformation1,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType3Code,
    DocumentType6Code,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionCreditTransferV10,
    FinancialInstitutionIdentification18,
    Garnishment3,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader96,
    Instruction4Code,
    InstructionForCreditorAgent3,
    InstructionForNextAgent1,
    LocalInstrument2Choice,
    NamePrefix2Code,
    OrganisationIdentification29,
    OrganisationIdentificationSchemeName1Choice,
    OtherContact1,
    Party38Choice,
    PartyIdentification135,
    PaymentIdentification13,
    PaymentTypeInformation28,
    PersonIdentification13,
    PersonIdentificationSchemeName1Choice,
    PostalAddress24,
    PreferredContactMethod1Code,
    Priority2Code,
    Priority3Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    Purpose2Choice,
    ReferredDocumentInformation7,
    ReferredDocumentType3Choice,
    ReferredDocumentType4,
    RemittanceAmount2,
    RemittanceAmount3,
    RemittanceInformation2,
    RemittanceInformation21,
    ServiceLevel8Choice,
    SettlementDateTimeIndication1,
    SettlementInstruction11,
    SettlementMethod1Code,
    SettlementTimeRequest2,
    StructuredRemittanceInformation17,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount3,
    TaxAmountAndType1,
    TaxAmountType1Choice,
    TaxAuthorisation1,
    TaxData1,
    TaxInformation10,
    TaxParty1,
    TaxParty2,
    TaxPeriod3,
    TaxRecord3,
    TaxRecordDetails3,
    TaxRecordPeriod1Code,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "BranchAndFinancialInstitutionIdentification6",
    "BranchData3",
    "CashAccount40",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemIdentification3Choice",
    "ClearingSystemMemberIdentification2",
    "Contact4",
    "CreditDebitCode",
    "CreditTransferTransaction52",
    "CreditTransferTransaction56",
    "CreditorReferenceInformation2",
    "CreditorReferenceType1Choice",
    "CreditorReferenceType2",
    "DateAndPlaceOfBirth1",
    "DatePeriod2",
    "DiscountAmountAndType1",
    "DiscountAmountType1Choice",
    "Document",
    "DocumentAdjustment1",
    "DocumentLineIdentification1",
    "DocumentLineInformation1",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType3Code",
    "DocumentType6Code",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionCreditTransferV10",
    "FinancialInstitutionIdentification18",
    "Garnishment3",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader96",
    "Instruction4Code",
    "InstructionForCreditorAgent3",
    "InstructionForNextAgent1",
    "LocalInstrument2Choice",
    "NamePrefix2Code",
    "OrganisationIdentification29",
    "OrganisationIdentificationSchemeName1Choice",
    "OtherContact1",
    "Party38Choice",
    "PartyIdentification135",
    "PaymentIdentification13",
    "PaymentTypeInformation28",
    "PersonIdentification13",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress24",
    "PreferredContactMethod1Code",
    "Priority2Code",
    "Priority3Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "Purpose2Choice",
    "ReferredDocumentInformation7",
    "ReferredDocumentType3Choice",
    "ReferredDocumentType4",
    "RemittanceAmount2",
    "RemittanceAmount3",
    "RemittanceInformation2",
    "RemittanceInformation21",
    "ServiceLevel8Choice",
    "SettlementDateTimeIndication1",
    "SettlementInstruction11",
    "SettlementMethod1Code",
    "SettlementTimeRequest2",
    "StructuredRemittanceInformation17",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount3",
    "TaxAmountAndType1",
    "TaxAmountType1Choice",
    "TaxAuthorisation1",
    "TaxData1",
    "TaxInformation10",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod3",
    "TaxRecord3",
    "TaxRecordDetails3",
    "TaxRecordPeriod1Code",
]



from pyiso20022.pacs.pacs_010_001_06.pacs_010_001_06 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    CashAccount40,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    CreditTransferTransaction66,
    DirectDebitTransactionInformation33,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionDirectDebitV06,
    FinancialInstitutionIdentification23,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    GroupHeader119,
    InstructionForCreditorAgent3,
    LocalInstrument2Choice,
    PaymentIdentification13,
    PaymentTypeInformation28,
    PostalAddress27,
    Priority2Code,
    Priority3Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    Purpose2Choice,
    RemittanceInformation2,
    ServiceLevel8Choice,
    SettlementDateTimeIndication1,
    SettlementTimeRequest2,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "CashAccount40",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "CreditTransferTransaction66",
    "DirectDebitTransactionInformation33",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionDirectDebitV06",
    "FinancialInstitutionIdentification23",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "GroupHeader119",
    "InstructionForCreditorAgent3",
    "LocalInstrument2Choice",
    "PaymentIdentification13",
    "PaymentTypeInformation28",
    "PostalAddress27",
    "Priority2Code",
    "Priority3Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "Purpose2Choice",
    "RemittanceInformation2",
    "ServiceLevel8Choice",
    "SettlementDateTimeIndication1",
    "SettlementTimeRequest2",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.pacs.pacs_010_001_02.pacs_010_001_02 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    AddressType2Code,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    CashAccount24,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    CreditTransferTransaction9,
    DirectDebitTransactionInformation15,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionDirectDebitV02,
    FinancialInstitutionIdentification8,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GroupHeader63,
    Instruction5Code,
    InstructionForCreditorAgent2,
    LocalInstrument2Choice,
    PaymentIdentification3,
    PaymentTypeInformation21,
    PostalAddress6,
    Priority2Code,
    Priority3Code,
    RemittanceInformation2,
    ServiceLevel8Choice,
    SettlementTimeRequest2,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "AddressType2Code",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "CashAccount24",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "CreditTransferTransaction9",
    "DirectDebitTransactionInformation15",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionDirectDebitV02",
    "FinancialInstitutionIdentification8",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GroupHeader63",
    "Instruction5Code",
    "InstructionForCreditorAgent2",
    "LocalInstrument2Choice",
    "PaymentIdentification3",
    "PaymentTypeInformation21",
    "PostalAddress6",
    "Priority2Code",
    "Priority3Code",
    "RemittanceInformation2",
    "ServiceLevel8Choice",
    "SettlementTimeRequest2",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.camt.camt_056_001_09.camt_056_001_09 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    AmendmentInformationDetails13,
    AmountType4Choice,
    BranchAndFinancialInstitutionIdentification6,
    BranchData3,
    CancellationReason33Choice,
    Case5,
    CaseAssignment5,
    CashAccount38,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemIdentification3Choice,
    ClearingSystemMemberIdentification2,
    Contact4,
    ControlData1,
    CreditDebitCode,
    CreditorReferenceInformation2,
    CreditorReferenceType1Choice,
    CreditorReferenceType2,
    CreditTransferMandateData1,
    DateAndDateTime2Choice,
    DateAndPlaceOfBirth1,
    DatePeriod2,
    DiscountAmountAndType1,
    DiscountAmountType1Choice,
    Document,
    DocumentAdjustment1,
    DocumentLineIdentification1,
    DocumentLineInformation1,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType3Code,
    DocumentType6Code,
    EquivalentAmount2,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification18,
    FitoFipaymentCancellationRequestV09,
    Frequency6Code,
    Frequency36Choice,
    FrequencyAndMoment1,
    FrequencyPeriod1,
    Garnishment3,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    LocalInstrument2Choice,
    MandateClassification1Choice,
    MandateClassification1Code,
    MandateRelatedData1Choice,
    MandateRelatedInformation14,
    MandateSetupReason1Choice,
    MandateTypeInformation2,
    NamePrefix2Code,
    OrganisationIdentification29,
    OrganisationIdentificationSchemeName1Choice,
    OriginalGroupHeader15,
    OriginalGroupInformation29,
    OriginalTransactionReference31,
    OtherContact1,
    Party38Choice,
    Party40Choice,
    PartyIdentification135,
    PaymentCancellationReason5,
    PaymentMethod4Code,
    PaymentTransaction120,
    PaymentTypeInformation27,
    PersonIdentification13,
    PersonIdentificationSchemeName1Choice,
    PostalAddress24,
    PreferredContactMethod1Code,
    Priority2Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    Purpose2Choice,
    ReferredDocumentInformation7,
    ReferredDocumentType3Choice,
    ReferredDocumentType4,
    RemittanceAmount2,
    RemittanceAmount3,
    RemittanceInformation16,
    SequenceType3Code,
    ServiceLevel8Choice,
    SettlementInstruction7,
    SettlementMethod1Code,
    StructuredRemittanceInformation16,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount2,
    TaxAmountAndType1,
    TaxAmountType1Choice,
    TaxAuthorisation1,
    TaxInformation7,
    TaxParty1,
    TaxParty2,
    TaxPeriod2,
    TaxRecord2,
    TaxRecordDetails2,
    TaxRecordPeriod1Code,
    UnderlyingTransaction26,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "AmendmentInformationDetails13",
    "AmountType4Choice",
    "BranchAndFinancialInstitutionIdentification6",
    "BranchData3",
    "CancellationReason33Choice",
    "Case5",
    "CaseAssignment5",
    "CashAccount38",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemIdentification3Choice",
    "ClearingSystemMemberIdentification2",
    "Contact4",
    "ControlData1",
    "CreditDebitCode",
    "CreditTransferMandateData1",
    "CreditorReferenceInformation2",
    "CreditorReferenceType1Choice",
    "CreditorReferenceType2",
    "DateAndDateTime2Choice",
    "DateAndPlaceOfBirth1",
    "DatePeriod2",
    "DiscountAmountAndType1",
    "DiscountAmountType1Choice",
    "Document",
    "DocumentAdjustment1",
    "DocumentLineIdentification1",
    "DocumentLineInformation1",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType3Code",
    "DocumentType6Code",
    "EquivalentAmount2",
    "FitoFipaymentCancellationRequestV09",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification18",
    "Frequency36Choice",
    "Frequency6Code",
    "FrequencyAndMoment1",
    "FrequencyPeriod1",
    "Garnishment3",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "LocalInstrument2Choice",
    "MandateClassification1Choice",
    "MandateClassification1Code",
    "MandateRelatedData1Choice",
    "MandateRelatedInformation14",
    "MandateSetupReason1Choice",
    "MandateTypeInformation2",
    "NamePrefix2Code",
    "OrganisationIdentification29",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalGroupHeader15",
    "OriginalGroupInformation29",
    "OriginalTransactionReference31",
    "OtherContact1",
    "Party38Choice",
    "Party40Choice",
    "PartyIdentification135",
    "PaymentCancellationReason5",
    "PaymentMethod4Code",
    "PaymentTransaction120",
    "PaymentTypeInformation27",
    "PersonIdentification13",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress24",
    "PreferredContactMethod1Code",
    "Priority2Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "Purpose2Choice",
    "ReferredDocumentInformation7",
    "ReferredDocumentType3Choice",
    "ReferredDocumentType4",
    "RemittanceAmount2",
    "RemittanceAmount3",
    "RemittanceInformation16",
    "SequenceType3Code",
    "ServiceLevel8Choice",
    "SettlementInstruction7",
    "SettlementMethod1Code",
    "StructuredRemittanceInformation16",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount2",
    "TaxAmountAndType1",
    "TaxAmountType1Choice",
    "TaxAuthorisation1",
    "TaxInformation7",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod2",
    "TaxRecord2",
    "TaxRecordDetails2",
    "TaxRecordPeriod1Code",
    "UnderlyingTransaction26",
]



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional

from xsdata.models.datatype import XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01"


@dataclass
class Case:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    cretr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cretr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    reop_case_indctn: Optional[bool] = field(
        default=None,
        metadata={
            "name": "ReopCaseIndctn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
        },
    )


@dataclass
class CaseAssignment:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    assgnr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Assgnr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    assgne: Optional[str] = field(
        default=None,
        metadata={
            "name": "Assgne",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    cre_dt_tm: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
        },
    )


@dataclass
class CurrencyAndAmount:
    value: Optional[Decimal] = field(
        default=None,
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        },
    )


class UnableToApplyIncorrectInfo1Code(Enum):
    IN01 = "IN01"
    IN02 = "IN02"
    IN03 = "IN03"
    IN04 = "IN04"
    IN05 = "IN05"
    IN06 = "IN06"
    IN07 = "IN07"
    IN08 = "IN08"
    IN09 = "IN09"
    IN10 = "IN10"
    IN11 = "IN11"
    IN12 = "IN12"
    IN13 = "IN13"
    IN14 = "IN14"
    IN15 = "IN15"
    IN16 = "IN16"
    IN17 = "IN17"
    IN18 = "IN18"
    IN19 = "IN19"
    MM20 = "MM20"
    MM21 = "MM21"
    MM22 = "MM22"


class UnableToApplyMissingInfo1Code(Enum):
    MS01 = "MS01"
    MS02 = "MS02"
    MS03 = "MS03"
    MS04 = "MS04"
    MS05 = "MS05"
    MS06 = "MS06"
    MS07 = "MS07"
    MS08 = "MS08"
    MS09 = "MS09"
    MS10 = "MS10"
    MS11 = "MS11"
    MS12 = "MS12"
    MS13 = "MS13"
    MS14 = "MS14"


@dataclass
class MissingOrIncorrectInformation:
    mssng_inf: List[UnableToApplyMissingInfo1Code] = field(
        default_factory=list,
        metadata={
            "name": "MssngInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "max_occurs": 10,
        },
    )
    incrrct_inf: List[UnableToApplyIncorrectInfo1Code] = field(
        default_factory=list,
        metadata={
            "name": "IncrrctInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "max_occurs": 10,
        },
    )


@dataclass
class PaymentInstructionExtract:
    assgnr_instr_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "AssgnrInstrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    assgne_instr_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "AssgneInstrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ccy_amt: Optional[CurrencyAndAmount] = field(
        default=None,
        metadata={
            "name": "CcyAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
        },
    )
    val_dt: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
        },
    )


@dataclass
class UnableToApplyJustificationChoice:
    any_inf: Optional[bool] = field(
        default=None,
        metadata={
            "name": "AnyInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
        },
    )
    mssng_or_incrrct_inf: Optional[MissingOrIncorrectInformation] = field(
        default=None,
        metadata={
            "name": "MssngOrIncrrctInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
        },
    )


@dataclass
class Camt02600101:
    class Meta:
        name = "camt.026.001.01"

    assgnmt: Optional[CaseAssignment] = field(
        default=None,
        metadata={
            "name": "Assgnmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
        },
    )
    case: Optional[Case] = field(
        default=None,
        metadata={
            "name": "Case",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
        },
    )
    undrlyg: Optional[PaymentInstructionExtract] = field(
        default=None,
        metadata={
            "name": "Undrlyg",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
        },
    )
    justfn: Optional[UnableToApplyJustificationChoice] = field(
        default=None,
        metadata={
            "name": "Justfn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01",
            "required": True,
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:camt.026.001.01"

    camt_026_001_01: Optional[Camt02600101] = field(
        default=None,
        metadata={
            "name": "camt.026.001.01",
            "type": "Element",
            "required": True,
        },
    )
